/*
 * Copyright 2018 Alexis Lopes Zubeta <contact@azubieta.net>
 * Copyright 2020 Tomaz Canabrava <tcanabrava@kde.org>
 * Copyright 2020 Kai Uwe Broulik <kde@broulik.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.12

import org.kde.kirigami 2.10 as Kirigami

import org.kcm.firewall 1.0

ViewBase {
    title: i18n("Connections")

    model: netStatClient.connectionsModel
    roles: [
        {title: i18n("Protocol"), role: "protocol", width: Kirigami.Units.gridUnit * 4},
        {title: i18n("Local Address"), role: "localAddress", width: Kirigami.Units.gridUnit * 10},
        {title: i18n("Foreign Address"), role: "foreignAddress", width: Kirigami.Units.gridUnit * 10},
        {title: i18n("Status"), role: "status", width: Kirigami.Units.gridUnit * 5},
        {title: i18n("PID"), role: "pid", width: Kirigami.Units.gridUnit * 3},
        {title: i18n("Program"), role: "program", width: Kirigami.Units.gridUnit * 7}
    ]
    defaultSortRole: "program"
    emptyListText: i18n("There are currently no open connections.")

    blacklistRuleFactory: kcm.client.createRuleFromConnection
    blacklistRuleRoleNames: [
        "Protocol",
        "LocalAddress",
        "ForeignAddress",
        "Status"
    ]
    blacklistRuleSuccessMessage: i18n("Created a blacklist rule from this connection.");

    filterRoleNames: blacklistRuleRoleNames.concat(["Pid", "Program"])

    NetstatClient {
        id: netStatClient
    }
}
